@@ -31,7 +31,7 @@ def next_neighbors_periodic(p, ps, k):
     # sort by distance
     value_index_sorted = sorted(value_index, key=lambda s: s[0])
     # take first k indices with least distance and sort them
-    return sorted(list(map(lambda s: s[1], value_index_sorted[0:k])))
+    return sorted(map(lambda s: s[1], value_index_sorted[0:k]))
 
 
 def next_neighbors(p, ps, k):
@@ -57,7 +57,7 @@ def next_neighbors(p, ps, k):
     # sort by distance
     value_index_sorted = sorted(value_index, key=lambda s: s[0])
     # take first k indices with least distance and sort them
-    return sorted(list(map(lambda s: s[1], value_index_sorted[0:k])))
+    return sorted(map(lambda s: s[1], value_index_sorted[0:k]))
 
 
 def continue_periodic_array(arr, nn):
@@ -266,7 +266,7 @@ def border_padding(grid, l, r, pad_type='mirror'):
 
     assert l < grid.size and r < grid.size
     padded_arr = np.zeros(grid.size + l + r)
-    if pad_type is 'mirror':
+    if pad_type == 'mirror':
         for i in range(l):
             padded_arr[i] = 2 * grid[0] - grid[l - i]
         for j in range(r):
