@@ -54,7 +54,7 @@ class fenics_heat(ptype):
 
         # set mesh and refinement (for multilevel)
         mesh = df.UnitIntervalMesh(problem_params['c_nvars'])
-        for i in range(problem_params['refinements']):
+        for _ in range(problem_params['refinements']):
             mesh = df.refine(mesh)
 
         # define function space for future reference
